==> v1.0.0.zip: kintone-plugin-docx/src/config/Settings.tsx <==
import React from 'react';

import { KintoneRestAPIClient } from '@kintone/rest-api-client';
import { Properties as KintoneFormFieldProperties } from '@kintone/rest-api-client/lib/src/client/types';
import moize from 'moize';
import invariant from 'tiny-invariant';
import { PLUGIN_ID } from '../common/global';
import KintonePluginAlert from '../common/ui/KintonePluginAlert';
import KintonePluginButton from '../common/ui/KintonePluginButton';
import KintonePluginDesc from '../common/ui/KintonePluginDesc';
import KintonePluginLabel from '../common/ui/KintonePluginLabel';
import KintonePluginRequire from '../common/ui/KintonePluginRequire';
import KintonePluginRow from '../common/ui/KintonePluginRow';
import KintonePluginSelect, { KintonePluginSelectOptionData } from '../common/ui/KintonePluginSelect';
import KintonePluginTitle from '../common/ui/KintonePluginTitle';

import styles from './Settings.module.css';

const cachedFormFieldsProperties = moize.promise(async (appId: number): Promise<KintoneFormFieldProperties> => {
  const client = new KintoneRestAPIClient();
  const { properties } = await client.app.getFormFields({ app: appId, lang: 'en', preview: false });
  return properties;
});

const Settings: React.FC = () => {
  const config = kintone.plugin.app.getConfig(PLUGIN_ID);
  const appId = kintone.app.getId();
  invariant(appId, 'The app ID is not available. Please ensure you are on a Kintone app page.');
  const properties = React.use(cachedFormFieldsProperties(appId));
  const fileFields = Object.values(properties).filter((property) => property.type === 'FILE');
  const options: KintonePluginSelectOptionData[] = [
    { key: '-', value: '', label: 'Select a File field', disabled: true }, // Default option
    ...fileFields.map((property) => ({
      key: property.code,
      value: property.code,
      label: property.label,
    })),
  ];

  const [template, setTemplate] = React.useState<string>(
    () => options.find((option) => option.value === (config.template ?? ''))?.value ?? '',
  );

  const handleOnSubmit = (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    kintone.plugin.app.setConfig({ template }, () => {
      alert('The plug-in settings have been saved. Please update the app!');
      window.location.href = `../../flow?app=${appId}`;
    });
  };

  const handleOnChangeTemplate = (e: React.ChangeEvent<HTMLSelectElement>) => {
    setTemplate(e.target.value);
  };

  const handleOnClickCancel = () => {
    window.location.href = `../../${appId}/plugin/`;
  };

  return (
    <section className="settings">
      <KintonePluginLabel>Settings for the Kintone Word output plugin</KintonePluginLabel>
      <form onSubmit={handleOnSubmit}>
        <KintonePluginRow>
          <KintonePluginTitle>
            Template<KintonePluginRequire>*</KintonePluginRequire>
          </KintonePluginTitle>
          <KintonePluginDesc>Select a file field that contains the Word template file.</KintonePluginDesc>
          {fileFields.length === 0 ? (
            <KintonePluginAlert>
              No file fields found in the app. Please add a file field to use this plugin.
            </KintonePluginAlert>
          ) : (
            <KintonePluginSelect defaultValue={template} onChange={handleOnChangeTemplate} options={options} />
          )}
        </KintonePluginRow>
        <KintonePluginRow className={styles.buttons}>
          <KintonePluginButton variant="dialog-cancel" type="button" onClick={handleOnClickCancel}>
            Cancel
          </KintonePluginButton>
          <KintonePluginButton variant="dialog-ok" type="submit">
            Save
          </KintonePluginButton>
        </KintonePluginRow>
      </form>
    </section>
  );
};
export default Settings;

==> v1.0.2.zip: kintone-plugin-docx/src/config/Settings.tsx <==
import React from 'react';

import { KintoneRestAPIClient } from '@kintone/rest-api-client';
import moize from 'moize';
import { useTranslation } from 'react-i18next';
import invariant from 'tiny-invariant';
import { naturalCompare } from '../common/stringUtils';
import { KintoneFormFieldProperties } from '../common/types';
import KintonePluginAlert from '../common/ui/KintonePluginAlert';
import KintonePluginButton from '../common/ui/KintonePluginButton';
import KintonePluginDesc from '../common/ui/KintonePluginDesc';
import KintonePluginLabel from '../common/ui/KintonePluginLabel';
import KintonePluginRequire from '../common/ui/KintonePluginRequire';
import KintonePluginRow from '../common/ui/KintonePluginRow';
import KintonePluginSelect, { KintonePluginSelectOptionData } from '../common/ui/KintonePluginSelect';
import KintonePluginTitle from '../common/ui/KintonePluginTitle';

import styles from './Settings.module.css';

const cachedFormFieldsProperties = moize.promise(async (appId: number): Promise<KintoneFormFieldProperties> => {
  const client = new KintoneRestAPIClient();
  const { properties } = await client.app.getFormFields({ app: appId, preview: true });
  return properties;
});

interface SettingsProps {
  pluginId: string;
}

const Settings: React.FC<SettingsProps> = (props) => {
  const { pluginId } = props;
  const { t } = useTranslation();
  const config = kintone.plugin.app.getConfig(pluginId);
  const appId = kintone.app.getId();
  invariant(appId, 'The app ID is not available. Please ensure you are on a Kintone app page.');
  const properties = React.use(cachedFormFieldsProperties(appId));
  const fileFields = Object.values(properties)
    .filter((property) => property.type === 'FILE')
    .sort((a, b) => naturalCompare(`${a.label} (${a.code})`, `${b.label} (${b.code})`));
  const options: KintonePluginSelectOptionData[] = [
    { value: '', label: t('settings.template.messages.select-an-attachment-fields'), disabled: true }, // Default option
    ...fileFields.map((property) => ({
      value: property.code,
      label: `${property.label} (${property.code})`,
    })),
  ];

  const [template, setTemplate] = React.useState<string>(
    () => options.find((option) => option.value === (config.template ?? ''))?.value ?? '',
  );

  const handleOnSubmit = (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    kintone.plugin.app.setConfig({ template }, () => {
      alert(t('on-saved'));
      window.location.href = `../../flow?app=${appId}`;
    });
  };

  const handleOnChangeTemplate = (value: string) => {
    setTemplate(value);
  };

  const handleOnClickCancel = () => {
    window.location.href = `../../${appId}/plugin/`;
  };

  return (
    <section className="settings">
      <KintonePluginLabel>{t('title')}</KintonePluginLabel>
      <form onSubmit={handleOnSubmit}>
        <KintonePluginRow>
          <KintonePluginTitle>
            {t('settings.template.title')}
            <KintonePluginRequire>*</KintonePluginRequire>
          </KintonePluginTitle>
          <KintonePluginDesc> {t('settings.template.description')}</KintonePluginDesc>
          {fileFields.length === 0 ? (
            <KintonePluginAlert>{t('settings.template.errors.no-attachment-field-found')}</KintonePluginAlert>
          ) : (
            <KintonePluginSelect value={template} onChange={handleOnChangeTemplate} options={options} />
          )}
        </KintonePluginRow>
        <KintonePluginRow className={styles.buttons}>
          <KintonePluginButton variant="dialog-cancel" type="button" onClick={handleOnClickCancel}>
            {t('buttons.cancel')}
          </KintonePluginButton>
          <KintonePluginButton variant="dialog-ok" type="submit">
            {t('buttons.save')}
          </KintonePluginButton>
        </KintonePluginRow>
      </form>
    </section>
  );
};
export default Settings;
